"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var R = _interopRequireWildcard(require("ramda"));

var _fp = require("./fp");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

/**
 * Apply all hocs to the object's value(component),
 * return new key->value object { pathOfComponent: hocs(component) }
 *
 * @param {*object} allComponents object of key->value, [key] is the path of the component, [value] is the component
 * @param {*} funcs hoc
 */
var makeWidgetMap = function makeWidgetMap(allComponents) {
  for (var _len = arguments.length, funcs = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    funcs[_key - 1] = arguments[_key];
  }

  if (!funcs || funcs.length === 0) {
    // return original mapping if hocs is not defined
    return allComponents;
  }

  var getPropFromAllComponents = function getPropFromAllComponents(name) {
    return R.prop(name, allComponents);
  };

  var makeNewComponent = R.compose(R.pipe.apply(R, funcs), getPropFromAllComponents);
  var validComponentNames = R.filter(_fp.isString, R.keys(allComponents));
  var validComponents = R.map(makeNewComponent)(validComponentNames);
  return R.compose(R.fromPairs, R.zip(validComponentNames))(validComponents);
};

var _default = makeWidgetMap;
exports.default = _default;
module.exports = exports.default;